Pyng
====
A pure-Python ping wrapper for pretty and fast network assessment.

Requirements
------------
* Python 3.6+
* Mac/Linux

Features
--------
* colorized output for easy visualization
* log scale to handle all ranges of latency
* specify host and number of pings (-1 is infinite)
* < 80 characters wide!

Un-Features
-----------
* Not tested on Linux
* No support for specifying ping rate
